package zllauth1

import (
	"crypto/rand"
	"fmt"
	"io"
	"strings"
)

func GenerateRandomJWTKey(length int) ([]byte, error) {
	buf := make([]byte, length)
	n, err := io.ReadFull(rand.Reader, buf)
	if err != nil {
		return []byte{}, err
	}
	if n != length {
		return []byte{}, fmt.Errorf("failed generate random jwt key with specified length")
	}
	return buf, nil
}

func SM2PubKeyCombine(x, y string) string {
	sb := strings.Builder{}
	lx, ly := len(x), len(y)
	lpx, lpy := 64-lx, 64-ly
	spx := strings.Repeat("0", lpx)
	spy := strings.Repeat("0", lpy)
	sb.WriteString(spx)
	sb.WriteString(x)
	sb.WriteString(spy)
	sb.WriteString(y)
	return sb.String()
}
